/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import React, { } from "react";
import { StyleSheet, View, Text } from "react-native";
import { Chip } from "react-native-paper";
import { useAuth } from "../../../../data/Auth/AuthContext";
import { Landmark } from "../../../../data/landmarks";
import { MainTabsNavigationProp } from "../../../../navigation/MainTabsNavigator";


interface TagContainerProps {
    landmark?: Landmark
    tagLandmark: (tagType: string) => void
    toggleLmDetails: (state: boolean) => void
    authNavigation: MainTabsNavigationProp
    taggedByUser?: Array<boolean>
}

export const TagContainer: React.FC<TagContainerProps> = (props) => {
    const { anonUserId, setAlert } = useAuth()
    return (
        <View style={styles.tagContainer}>
            <View style={styles.tagRow}>
                <Chip selected={props.taggedByUser?.[0]} mode="flat" icon="check" style={styles.tag} onPress={() => {
                    if (anonUserId) {
                        setAlert({
                            title: "Authentication required",
                            type: "warning",
                            message: "Oops! In order to tag landmarks, you have to log in.",
                            callback: () => { props.toggleLmDetails(false); props.authNavigation.navigate("Account") },
                            callbackButtonText: 'Go to login'
                        });
                    }
                    else {
                        props.tagLandmark("positive")
                    }
                }}>
                    Positive | {props.landmark?.tag_positive}
                </Chip>
                <Chip selected={props?.taggedByUser?.[1]} mode="flat" icon="close" style={styles.tag} onPress={() => {
                    if (anonUserId) {
                        setAlert({
                            title: "Authentication required",
                            type: "warning",
                            message: "Oops! In order to tag landmarks, you have to log in.",
                            callback: () => { props.toggleLmDetails(false); props.authNavigation.navigate("Account") },
                            callbackButtonText: 'Go to login'
                        });
                    }
                    else {
                        props.tagLandmark("negative")
                    }
                }}>
                    Negative | {props.landmark?.tag_negative}
                </Chip>
                <Chip selected={props?.taggedByUser?.[2]} mode="flat" icon="calendar-remove" style={styles.tag} onPress={() => {
                    if (anonUserId) {
                        setAlert({
                            title: "Authentication required",
                            type: "warning",
                            message: "Oops! In order to tag landmarks, you have to log in.",
                            callback: () => { props.toggleLmDetails(false); props.authNavigation.navigate("Account") },
                            callbackButtonText: 'Go to login'
                        });
                    }
                    else {
                        props.tagLandmark("stale")
                    }
                }}>
                    Stale | {props.landmark?.tag_stale}
                </Chip>
            </View>
            <View style={styles.tagRow}>
                <Chip selected={props?.taggedByUser?.[3]} mode="flat" icon="content-copy" style={styles.tag} onPress={() => {
                    if (anonUserId) {
                        setAlert({
                            title: "Authentication required",
                            type: "warning",
                            message: "Oops! In order to tag landmarks, you have to log in.",
                            callback: () => { props.toggleLmDetails(false); props.authNavigation.navigate("Account") },
                            callbackButtonText: 'Go to login'
                        });
                    }
                    else {
                        props.tagLandmark("duplicate")
                    }
                }}>
                    Duplicate | {props.landmark?.tag_duplicate}
                </Chip>
                <Chip selected={props?.taggedByUser?.[4]} mode="flat" icon="map-marker" style={styles.tag} onPress={() => {
                    if (anonUserId) {
                        setAlert({
                            title: "Authentication required",
                            type: "warning",
                            message: "Oops! In order to tag landmarks, you have to log in.",
                            callback: () => { props.toggleLmDetails(false); props.authNavigation.navigate("Account") },
                            callbackButtonText: 'Go to login'
                        });
                    }
                    else {
                        props.tagLandmark("imprecise")
                    }
                }}>
                    Imprecise Location | {props.landmark?.tag_imprecise}
                </Chip>
            </View>
        </View>
    )
}

const styles = StyleSheet.create({
    tagContainer: {
        marginBottom: 20,
    },
    tagRow: {
        flex: 1,
        flexDirection: "row",
        marginBottom: 5,
        justifyContent: "flex-start",
    },
    tag: {
        margin: 2,
        // backgroundColor: "#ADADAD",
    },
    tagText: {
        color: "#FF0000",
    }
})